@@ -1,6 +1,6 @@
 ;;; (www http) --- HTTP client library
 
-;; Copyright (C) 2008, 2009, 2011, 2012, 2013 Thien-Thi Nguyen
+;; Copyright (C) 2008, 2009, 2011, 2012, 2013, 2015 Thien-Thi Nguyen
 ;; Copyright (C) 1997, 2001, 2002, 2003, 2004, 2005,
 ;;   2006, 2007 Free Software Foundation, Inc.
 ;;
@@ -137,7 +137,7 @@
 (define (msg-body! msg string)   (vector-set! msg 4 string))
 
 (define (msg-string-rcode! msg)
-  (vector-set! msg 1 (fs "~A" (vector-ref msg 1))))
+  (vector-set! msg 1 (number->string (vector-ref msg 1))))
 
 
 ;; Submit an http request using the @code{POST} method on the @var{url}.
@@ -409,7 +409,7 @@
 ;; Submit an HTTP request using @var{method} and @var{url}, wait
 ;; for a response, and return the response as an HTTP message object.
 ;; The field types and values of this message object are as described in
-;; @code{receive-response}, with two exceptions (for backward compatability):
+;; @code{receive-response}, with two exceptions (for backward compatibility):
 ;; the status code is a string; the header names are symbols, all lower-case.
 ;;
 ;; @var{method} is the symbolic name of some HTTP method, e.g.,
@@ -439,7 +439,7 @@
 ;;
 (define* (http:request method url #:optional (headers '()) (body '()))
   (cond ((symbol? method))
-        ;; Handle string ‘method’ for backward compatability.
+        ;; Handle string ‘method’ for backward compatibility.
         ((string? method) (set! method (string->symbol method)))
         (else (error "bad method:" method)))
   (let* ((sock (http:open (url:host url) (or (url:port url)
@@ -451,7 +451,7 @@
          (ans (receive-response get
                                 ;; Backward comptability; blech!
                                 #:s2s string-downcase)))
-    ;; Backward compatability; blech!
+    ;; Backward compatibility; blech!
     (msg-string-rcode! ans)
     ;; FIXME: what about keepalives?
     (close-port sock)
